#!/usr/bin/env perl

use warnings;
use strict;

use Getopt::Std;
use Pod::Usage;
use XML::Simple;

BEGIN {
  use FindBin qw($RealBin);
  BEGIN {
    unless ($ENV{'PPH'}) {
      my $binpath = $RealBin;
      $binpath =~ s|/[^/]+$||;
      $ENV{'PPH'} = $binpath;
    }
  }
  use lib "$ENV{PPH}/perl";
}

use PPH;
use SNP;
$| = 1;

#DDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDD

=head1 NAME

dump2tab.pl - print contents of PPH XML dump file(s) as a tab-separetd table

=head1 SYNOPSIS

dump2tab.pl xmlfile1 [xmlfile2 ...]

=head1 DESCRIPTION


=head1 AUTHOR

StS

=head1 SUBVERSION

 $LastChangedDate: 2009-11-28 00:15:09 -0500 (Sat, 28 Nov 2009) $
 $LastChangedRevision: 254 $
 $LastChangedBy: ivan $

=cut

#DDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDD

(@ARGV) or pod2usage();

my $pph = PPH->new();

print join "\t", "snp     ", "o_acc   ", "o_pos", $pph->return_header(); print "\n";
my $max_fields = scalar($pph->return_header());
foreach my $xmlf (@ARGV) {
  (-e $xmlf) or next;

  my $SNP = SNP->new_empty();
  $SNP->xml2snp($xmlf);

  my (@fields) = $pph->format_result($SNP);
  $#fields = ($max_fields - 1);
  print join "\t",
    sprintf("%-10s\t%-12s\t$SNP->{Pos}",
      $SNP->{SNP_Id}, (exists($SNP->{Orig_Acc}) ? $SNP->{Orig_Acc} : $SNP->{Acc})),
      map { defined($_) ? $_ : ''} @fields; print "\n";
}
