package PPH::Pfam;

use strict;
use warnings;

#DDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDD

=head1 NAME

Pfam - Using the swisspfam file to find out it a SNP lies within a domain

=head1 DESCRIPTION



=head1 AUTHOR

Steffen Schmidt

=head1 SUBVERSION

 $LastChangedDate: 2009-11-28 00:15:09 -0500 (Sat, 28 Nov 2009) $
 $LastChangedRevision: 254 $
 $LastChangedBy: ivan $

=cut

#DDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDD

BEGIN {
    #----------------------------------------
    # DEBUGGING
    #----------------------------------------
    use PPH::Config; # imports: $DEBUG @DEBUGGING_MODE %CONFIG
    if ($DEBUG) {
      # Test if we have Smart::Comments installed
      eval { require Smart::Comments; Smart::Comments->import(-ENV) };
      die "Please install Smart::Comments module or switch off verbose/DEBUG mode\n" if $@;
    }
    #----------------------------------------
}

#RRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRR

=head1 ROUTINES

=cut

#------------------------------------------------------------------------------

=head2 find_pfam

  Usage    : my $dom = $PPH::Pfam::find_pfam($SNP)
  Function : Find Pfam annotations to a given SNP
  Args     : Object of type SNP
  Returns  : $SNP->{Annot}{Domain}{ id, pfam, desc, from, to }

=cut

#----------------------------------------

sub find_pfam {
    my ($SNP) = shift;

    ### PPH Pfam find_pfam

    return 0 unless $SNP->{UniProt};

    #----------------------------------------
    # Reading the PFAM annot file created
    # by swisspfam.pl - a typical line looks
    # like:
    # acc     pfam            id      desc                    loc
    # P63104  PF00244.11      14-3-3  14-3-3 protein 1        3-236
    #----------------------------------------
    open my $F, '<', $CONFIG{PFAM} or die "PPH::Pfam - can't open Pfam file";
    while (<$F>) {
        chomp;
        my ($acc, $pfam, $id, $desc, @loc) = split /\t/;
        next unless $SNP->{Acc} eq $acc;
        foreach (@loc) {
            my ($from, $to) = split /-/, $_;

            next if ($SNP->{Pos} < $from or $SNP->{Pos} > $to);
            $SNP->{Annot}{Domain} =
                {
                    id    => $id,
                    pfam  => $pfam,
                    desc  => $desc,
                    from  => $from,
                    to    => $to
                };
            #### PPH Pfam find_pfam returns: $SNP->{Annot}{Domain}
            return 1;
        }
    }
    close $F;
    # nothing found
    return 0;
}

1;
