#!/bin/bash
#
# Edit the following two lines replacing @@...@@ placeholders with your
# MapSNPs database admin username and password.
#
MUSER=@@mapsnps_admin@@
MPASS=@@mapsnps_password@@
if [[ $# == 0 ]]; then
  echo "Error: No arguments specified"
  echo "Usage: loadtables.sh -d <hg18|hg19> <table1> <table2> <...>"
  exit 1
fi
DB=
if [[ "$1" == "-d" ]]; then
  shift
  DB="$1"
  shift
fi
if [[ -z "$DB" ]]; then
  echo "Error: Assembly database was not specified"
  echo "Usage: loadtables.sh -d <hg18|hg19> <table1> <table2> <...>"
  exit 1
fi
if [[ "$DB" != "hg18" && "$DB" != "hg19" ]]; then
  echo "Error: Unsupported assembly database: $DB"
  echo "Usage: loadtables.sh -d <hg18|hg19> <table1> <table2> <...>"
  exit 1
fi
if [[ $# == 0 ]]; then
  echo "Error: No tables specified"
  echo "Usage: loadtables.sh -d <hg18|hg19> <table1> <table2> <...>"
  exit 1
fi
echo "Creating database ${DB} ..."
mysql -u ${MUSER} -p${MPASS} -e "CREATE DATABASE IF NOT EXISTS ${DB}"
mysql -u ${MUSER} -p${MPASS} -e "GRANT SELECT, CREATE TEMPORARY TABLES, CREATE ROUTINE, ALTER ROUTINE, EXECUTE ON ${DB}.* TO ''@'localhost'"
for SQL in "$@"
do
  T_NAME=${SQL%%.sql}
  echo "Loading table ${T_NAME} ..."
  mysql -u ${MUSER} -p${MPASS} -e "DROP TABLE IF EXISTS ${T_NAME}" ${DB}
  mysql -u ${MUSER} -p${MPASS} ${DB} < ${T_NAME}.sql
  zcat "${T_NAME}.txt.gz" | mysql -u ${MUSER} -p${MPASS} --local-infile \
    -e "LOAD DATA LOCAL INFILE \"/dev/stdin\" INTO TABLE ${T_NAME}" ${DB}
  mysql -u ${MUSER} -p${MPASS} -e "ALTER TABLE ${T_NAME} ENABLE KEYS" ${DB}
done
